glydraw-package: glydraw: Draw Beautiful Symbol Nomenclature for Glycans

glydraw-packageR Documentation

glydraw: Draw Beautiful Symbol Nomenclature for Glycans

Description

logo

A 'ggplot2'-native plotting engine for drawing reproducible beautiful Symbol Nomenclature for Glycans (SNFG) glycan cartoons from glycan structure objects or text notations, with support for batch export, structural highlighting, and deep appearance customization. It follows the SNFG specification described at https://www.ncbi.nlm.nih.gov/glycans/snfg.html.

Author(s)

Maintainer: Bin Fu 23110220018@m.fudan.edu.cn (ORCID) [copyright holder]

Authors:

See Also

Useful links:


glydraw documentation built on July 25, 2026, 9:06 a.m.