Draw a Symbol Nomenclature For Glycan (SNFG)
Usage
draw_cartoon(
structure,
...,
show_linkage = TRUE,
orient = c("left", "right", "up", "down"),
highlight = NULL,
style = style_glydraw(),
red_end = NULL
)Arguments
- structure
A
glyrepr::glycan_structure()scalar, or a string of any glycan structure text nomenclatures supported byglyparse::auto_parse().- ...
Ignored.
- show_linkage
Show glycosidic linkage annotations or not. Default is TRUE. Substituent annotations are always shown.
- orient
Direction in which the glycan extends from its reducing end: one of
"left","right","up", or"down". Defaults to"left".- highlight
An integer vector specifying the node indices to highlight. This argument is applicable only when
structureis aglyrepr::glycan_structure(). Note that for aglyrepr::glycan_structure(), the node indices correspond exactly to the monosaccharides in its printed IUPAC nomenclature. For example, givenglyrepr::as_glycan_structure("Gal(b1-3)[GlcNAc(b1-6)]GalNAc(a1-"), settinghighlight = c(1, 3)will highlight the "Gal" and "GalNAc" nodes.- style
A
style_glydraw()object that controls the cartoon's visual appearance.- red_end
Reducing-end annotation.
NULL, the default, usesred_endfromstyle. A non-NULLvalue overridesstyle$red_end. Ignored whenstyle$red_end_lengthis0. To annotate an amino-acid sequence, tag its single glycosite as, for example,"ABC<site>D</site>EFG".
Examples
draw_cartoon("Gal(b1-3)GalNAc(a1-")
draw_cartoon(
"Gal(b1-3)GalNAc(a1-",
style = style_glydraw(font_family = "serif")
)