| glycanGrob | R Documentation |
glycanGrob() prepares the complete drawing specification for one glycan as
a grid grob. It is the low-level drawing primitive used by draw_cartoon().
glycanGrob(
structure,
...,
show_linkage = TRUE,
orient = c("H", "V"),
fuc_orient = c("flex", "up"),
red_end = "",
edge_linewidth = 0.8,
node_linewidth = 0.8,
node_size = 1,
colors = NULL,
highlight = NULL,
style = NULL
)
structure |
A |
... |
Ignored. |
show_linkage |
Show glycosidic linkage annotations or not. Default is TRUE. Substituent annotations are always shown. |
orient |
The orientation of glycan structure. "H" for horizontal, "V" for vertical. Default is "H" |
fuc_orient |
Fuc-like triangle orientation. |
red_end |
Reducing-end annotation. The default |
edge_linewidth |
Numeric scalar controlling the linewidth of linkage
lines. Defaults to the current value, |
node_linewidth |
Numeric scalar controlling the linewidth of node
borders. Defaults to the current value, |
node_size |
Numeric scalar used as a multiplier for the default node
size. Defaults to |
colors |
Optional named character vector of custom monosaccharide fill
colors. Names must be supported monosaccharide names, such as |
highlight |
An integer vector specifying the node indices to highlight.
This argument is applicable only when |
style |
A |
A glycanGrob object inheriting from grid::gTree().
grob <- glycanGrob("Gal(b1-3)GalNAc(a1-")
grid::grid.draw(grob)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.