| glydraw-package | R Documentation |
A 'ggplot2'-native plotting engine for drawing reproducible beautiful Symbol Nomenclature for Glycans (SNFG) glycan cartoons from glycan structure objects or text notations, with support for batch export, structural highlighting, and deep appearance customization. It follows the SNFG specification described at https://www.ncbi.nlm.nih.gov/glycans/snfg.html.
Maintainer: Bin Fu 23110220018@m.fudan.edu.cn (ORCID) [copyright holder]
Authors:
Xisong Feng 1225774778@qq.com (ORCID)
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.